Welcome to the package of pyTextMiner. The current version of pyTextMiner is 1.1.116.
For those who are interested in contributing to the development of pyTextMiner, please contact at min.song.njit@gmail.com.

pyTextMiner was originally designed with the architecture of pipeline.
Each of text representation and processing task is treated as a pipe. Thus, a pipeline consists of a set of text representation/preprocessing tasks

The current version of pyTextMiner supports Korean and English text.
